Learn R Programming

bayeslm (version 0.8.0)

plot.MCMC: Plot posterior summary

Description

plot.MCMC is an S3 method to plot empirical distribution of posterior draws. The input is a MCMC matrix

Usage

# S3 method for MCMC
plot(x,names,burnin=trunc(.1*nrow(X)),tvalues,TRACEPLOT=TRUE,DEN=TRUE,INT=TRUE,
      CHECK_NDRAWS=TRUE,... )

Arguments

x

A MCMC class matrix of posterior draws, such as bayeslm\$beta.

names

an optional character vector of names for the columns of X.

burnin

Number of draws to burn-in (default value is \(0.1*nrow(X)\)).

tvalues

vector of true values.

TRACEPLOT

logical, TRUE provide sequence plots of draws and acfs (default: TRUE)

DEN

logical, TRUE use density scale on histograms (default: TRUE)

INT

logical, TRUE put various intervals and points on graph (default: TRUE)

CHECK_NDRAWS

logical, TRUE check that there are at least 100 draws (default: TRUE)

...

optional arguments for generic function.

Details

This function is modified from package bayesm by Peter Rossi. It plots summary of posterior draws.

See Also

summary.bayeslm.fit

Examples

Run this code
# NOT RUN {
x = matrix(rnorm(1000), 100, 10)
y = x %*% rnorm(10) + rnorm(100)
fit=bayeslm(y~x)
plot(fit$beta)
# }

Run the code above in your browser using DataLab