This function summarize returned object of function bayeslm. It prints mean, std Dev, effective sample size (computed by function effectiveSize in package coda) coefficients posterior samples. If quantiles=TRUE, quantiles of marginal distirbutions in the columns of \(X\) are displayed.
The function also returns significance level, defined by whether the symmetric posterior quantile-based credible interval excludes zero. For example, a regression coefficient with one * has 0.025 quantile and 0.975 quantile with the same sign. Similarly, '***' denotes 0.0005 and 0.9995, '**' denotes 0.005 and 0.995, '*' denotes 0.025 and 0.975, '.' denotes 0.05 and 0.95 quantiles with the same sign.