powered by
plot.MCMC is an S3 method to plot empirical distribution of posterior draws. The input is a MCMC matrix
plot.MCMC
MCMC
# S3 method for MCMC plot(x,names,burnin=trunc(.1*nrow(X)),tvalues,TRACEPLOT=TRUE,DEN=TRUE,INT=TRUE, CHECK_NDRAWS=TRUE,... )
A MCMC class matrix of posterior draws, such as bayeslm\$beta.
bayeslm\$beta
an optional character vector of names for the columns of X.
X
Number of draws to burn-in (default value is \(0.1*nrow(X)\)).
vector of true values.
logical, TRUE provide sequence plots of draws and acfs (default: TRUE)
TRUE
logical, TRUE use density scale on histograms (default: TRUE)
logical, TRUE put various intervals and points on graph (default: TRUE)
logical, TRUE check that there are at least 100 draws (default: TRUE)
optional arguments for generic function.
This function is modified from package bayesm by Peter Rossi. It plots summary of posterior draws.
bayesm
summary.bayeslm.fit
# NOT RUN { x = matrix(rnorm(1000), 100, 10) y = x %*% rnorm(10) + rnorm(100) fit=bayeslm(y~x) plot(fit$beta) # }
Run the code above in your browser using DataLab